//LIBRARIES
#include <plib.h>
#include "NU32.h"

// Configuring the Device Configuration Registers
// 80Mhz Core/Periph, Pri Osc w/PLL, Write protect Boot Flash
#pragma config DEBUG    = OFF           // Background Debugger disabled
#pragma config FPLLMUL = MUL_20         // PLL Multiplier: Multiply by 20
#pragma config FPLLIDIV = DIV_2         // PLL Input Divider:  Divide by 2
#pragma config FPLLODIV = DIV_1         // PLL Output Divider: Divide by 1
#pragma config FWDTEN = OFF             // WD timer: OFF
#pragma config POSCMOD = HS             // Primary Oscillator Mode: High Speed xtal
#pragma config FNOSC = PRIPLL           // Oscillator Selection: Primary oscillator  w/ PLL
#pragma config FPBDIV = DIV_1           // Peripheral Bus Clock: Divide by 1
#pragma config BWP = OFF                // Boot write protect: OFF
#pragma config ICESEL = ICS_PGx2    // ICE pins configured on PGx2, Boot write protect OFF.
#pragma config FSOSCEN = OFF            // Disable second osc to get pins back

//GLOBAL CONSTANTS


//GLOBAL VARIABLES


//FUNCTION PROTOTYPES


//MAIN
int main(void)
{
	char messageArray[32];
	
    NU32_Startup();
    NU32_Initialize();

    DDPCONbits.JTAGEN = 0; // disable JTAG to get A4 and A5 back

    int j = 0;

    sprintf(messageArray,"Hello World!\r\n");
    NU32_WriteUART1(messageArray);

    while(1)
    {
        sprintf(messageArray,"Hello?\n");
        NU32_WriteUART1(messageArray);
        NU32LED1 = !NU32LED1; // toggle the LEDs
        NU32LED2 = !NU32LED2;
        // wait a little bit
        for (j=0;j<5000000;j++) {
            Nop();
        }
    }
    return 0;
}

//FUNCTIONS


//ISRs
void __ISR(_UART_1_VECTOR, ipl2) IntUart1Handler(void)
{
    // Is this an RX interrupt?
    if(INTGetFlag(INT_SOURCE_UART_RX(UART1)))
    {

        char data = UARTGetDataByte(UART1);
        PutCharacter(UART1,data);
        NU32LED1 = !NU32LED1;
        NU32LED2 = !NU32LED2;

        // Clear the RX interrupt Flag
        INTClearFlag(INT_SOURCE_UART_RX(UART1));
    }

    // We don't care about TX interrupt
    if(INTGetFlag(INT_SOURCE_UART_TX(UART1)))
    {
        INTClearFlag(INT_SOURCE_UART_TX(UART1));
    }
}

